@@ -1,4 +1,4 @@
-## $Id: detPhase.R 265 2010-04-13 14:47:20Z sluque $
+## $Id: detPhase.R 305 2010-06-22 02:06:03Z sluque $
 
 ".rleActivity" <- function(time, act, interval)
 {
@@ -25,16 +25,16 @@
          end.time=endtim)
 }
 
-".detPhase" <- function(time, depth, dry.thr, wet.thr, ...)
+".detPhase" <- function(time, depth, dry.thr, wet.thr, interval)
 {
-    ## Value: list with index of per-row activities, the activity code,
-    ## and start and end of each activity phase
+    ## Value: list with index of per-row activities, the activity code, and
+    ## start and end of each activity phase
     ## --------------------------------------------------------------------
     ## Arguments: time=chron vector with date/time depth=numeric vector
-    ## with depth readings (m) ...=sampling interval in POSIXct units (s),
-    ## to pass to rleActivity dry.thr=duration (in s) of on-land readings
-    ## that should be at-sea aquaerr=duration (in s) of at-sea readings to
-    ## be taken as leisure
+    ## with depth readings (m); interval=sampling interval in POSIXct units
+    ## (s), to pass to rleActivity; dry.thr=duration (in s) of on-land
+    ## readings that should be at-sea aquaerr=duration (in s) of at-sea
+    ## readings to be taken as leisure
     ## --------------------------------------------------------------------
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
@@ -45,16 +45,16 @@
     ## 10's when animal is wet; i.e. when depth is being recorded
     act[!is.na(depth)] <- "W"
     ## First run calculates times in each activity phase from the raw data
-    rawacts <- diveMove:::.rleActivity(time, act, ...)
+    rawacts <- diveMove:::.rleActivity(time, act, interval)
     ## On-land activity < 'dry.thr' should be considered still at-sea
     land <- levels(rawacts[[1]])[rawacts[[2]] < dry.thr]
     act[rawacts[[1]] %in% land & act == "L"] <- "W"
     ## Second run; at-sea phases < wet.thr should be leisure
-    leiacts <- diveMove:::.rleActivity(time, act, ...)
+    leiacts <- diveMove:::.rleActivity(time, act, interval)
     leisure <- levels(leiacts[[1]])[leiacts[[2]] < wet.thr]
     act[leiacts[[1]] %in% leisure & act == "W"] <- "Z"
     ## Final run to determine times with all corrected activities
-    finacts <- diveMove:::.rleActivity(time, act, ...)
+    finacts <- diveMove:::.rleActivity(time, act, interval)
     nphase <- length(levels(finacts[[1]]))
     if(act[1] == "L" & act[length(act)] == "L") {
         message("Record is complete\n", nphase, " phases detected")
